@@ -94,7 +94,16 @@ LpItem * lp_item_new(const char *key, const char *value){
 
 LpItem * lp_comment_new(const char *comment){
 	LpItem *item=lp_new0(LpItem,1);
+	char* pos = NULL;
 	item->value=ortp_strdup(comment);
+
+	pos=strchr(item->value,'\r');
+	if (pos==NULL)
+		pos=strchr(item->value,'\n');
+	
+	if(pos) {
+		*pos='\0'; /*replace the '\n' */
+	}
 	item->is_comment=TRUE;
 	return item;
 }
@@ -567,7 +576,7 @@ void lp_config_set_float(LpConfig *lpconfig,const char *section, const char *key
 
 void lp_item_write(LpItem *item, FILE *file){
 	if (item->is_comment)
-		fprintf(file,"%s",item->value);
+		fprintf(file,"%s\n",item->value);
 	else if (item->value && item->value[0] != '\0' )
 		fprintf(file,"%s=%s\n",item->key,item->value);
 	else {
@@ -696,18 +705,12 @@ const char* lp_config_get_default_string(const LpConfig *lpconfig, const char *s
 
 static char *_lp_config_dirname(char *path) {
 #ifdef _MSC_VER
-#ifdef WINAPI_FAMILY_PHONE_APP
 	char drive[_MAX_DRIVE];
 	char dir[_MAX_DIR];
 	char fname[_MAX_FNAME];
 	char ext[_MAX_EXT];
 	_splitpath(path, drive, dir, fname, ext);
 	return ms_strdup_printf("%s%s", drive, dir);
-#else
-	char *dir = ms_strdup(path);
-	PathRemoveFileSpec(dir);
-	return dir;
-#endif
 #else
 	char *tmp = ms_strdup(path);
 	char *dir = ms_strdup(dirname(tmp));
@@ -735,9 +738,14 @@ void lp_config_write_relative_file(const LpConfig *lpconfig, const char *filenam
 }
 
 int lp_config_read_relative_file(const LpConfig *lpconfig, const char *filename, char *data, size_t max_length) {
-	char *dir = _lp_config_dirname(lpconfig->filename);
-	char *filepath = ms_strdup_printf("%s/%s", dir, filename);
-	FILE *file = fopen(filepath, "r");
+	char *dir;
+	char *filepath;
+	FILE *file;
+
+	if (lpconfig->filename == NULL) return -1;
+	dir = _lp_config_dirname(lpconfig->filename);
+	filepath = ms_strdup_printf("%s/%s", dir, filename);
+	file = fopen(filepath, "r");
 	if(file != NULL) {
 		if(fread(data, 1, max_length, file)<=0) {
 			ms_error("%s could not be loaded. %s", filepath, strerror(errno));
