@@ -110,6 +110,8 @@ struct _LinphoneCallParams{
 	LinphonePrivacyMask privacy;
 	LinphoneMediaDirection audio_dir;
 	LinphoneMediaDirection video_dir;
+	bool_t video_declined; /*use to keep  traces of declined video to avoid to re-offer video in case of automatic RE-INVITE*/
+	bool_t internal_call_update; /*use mark that call update was requested internally (might be by ice)*/
 
 };
 
@@ -281,6 +283,8 @@ struct _LinphoneCall{
 	bool_t record_active;
 
 	bool_t paused_by_app;
+
+	MSWebCam *cam; /*webcam use for this call*/
 };
 
 BELLE_SIP_DECLARE_VPTR(LinphoneCall);
@@ -438,6 +442,9 @@ void linphone_core_stop_waiting(LinphoneCore *lc);
 int linphone_core_proceed_with_invite_if_ready(LinphoneCore *lc, LinphoneCall *call, LinphoneProxyConfig *dest_proxy);
 int linphone_core_start_invite(LinphoneCore *lc, LinphoneCall *call, const LinphoneAddress* destination/* = NULL if to be taken from the call log */);
 int linphone_core_restart_invite(LinphoneCore *lc, LinphoneCall *call);
+/*
+ * param automatic_offering aims is to take into account previous answer for video in case of automatic re-invite.
+ *  Purpose is to avoid to re-ask video previously declined */
 int linphone_core_start_update_call(LinphoneCore *lc, LinphoneCall *call);
 int linphone_core_start_accept_call_update(LinphoneCore *lc, LinphoneCall *call, LinphoneCallState next_state, const char *state_info);
 void linphone_core_notify_incoming_call(LinphoneCore *lc, LinphoneCall *call);
@@ -583,6 +590,7 @@ typedef struct sip_config
 	bool_t auto_net_state_mon;
 	bool_t tcp_tls_keepalive;
 	bool_t vfu_with_info; /*use to enable vfu request using sip info*/
+	bool_t save_auth_info; // if true, auth infos will be write in the config file when they are added to the list
 } sip_config_t;
 
 typedef struct rtp_config
@@ -801,6 +809,7 @@ struct _LinphoneCore
 	belle_tls_verify_policy_t *http_verify_policy;
 	MSList *tones;
 	LinphoneReason chat_deny_code;
+	char *file_transfer_server;
 	const char **supported_formats;
 	LinphoneContent *log_collection_upload_information;
 	LinphoneCoreVTable *current_vtable; // the latest vtable to call a callback, see linphone_core_get_current_vtable
@@ -1048,7 +1057,11 @@ static MS2_INLINE bool_t payload_type_enabled(const PayloadType *pt) {
 bool_t is_payload_type_number_available(const MSList *l, int number, const PayloadType *ignore);
 
 const MSCryptoSuite * linphone_core_get_srtp_crypto_suites(LinphoneCore *lc);
-MsZrtpCryptoTypesCount linphone_core_get_zrtp_key_agreements(LinphoneCore *lc, MSZrtpKeyAgreement keyAgreements[MS_MAX_ZRTP_CRYPTO_TYPES]);
+MsZrtpCryptoTypesCount linphone_core_get_zrtp_key_agreement_suites(LinphoneCore *lc, MSZrtpKeyAgreement keyAgreements[MS_MAX_ZRTP_CRYPTO_TYPES]);
+MsZrtpCryptoTypesCount linphone_core_get_zrtp_cipher_suites(LinphoneCore *lc, MSZrtpCipher ciphers[MS_MAX_ZRTP_CRYPTO_TYPES]);
+MsZrtpCryptoTypesCount linphone_core_get_zrtp_hash_suites(LinphoneCore *lc, MSZrtpHash hashes[MS_MAX_ZRTP_CRYPTO_TYPES]);
+MsZrtpCryptoTypesCount linphone_core_get_zrtp_auth_suites(LinphoneCore *lc, MSZrtpAuthTag authTags[MS_MAX_ZRTP_CRYPTO_TYPES]);
+MsZrtpCryptoTypesCount linphone_core_get_zrtp_sas_suites(LinphoneCore *lc, MSZrtpSasType sasTypes[MS_MAX_ZRTP_CRYPTO_TYPES]);
 
 /** Belle Sip-based objects need unique ids
   */
@@ -1114,6 +1127,37 @@ void set_playback_gain_db(AudioStream *st, float gain);
 LinphoneMediaDirection media_direction_from_sal_stream_dir(SalStreamDir dir);
 SalStreamDir sal_dir_from_call_params_dir(LinphoneMediaDirection cpdir);
 
+/*****************************************************************************
+ * LINPHONE CONTENT PRIVATE ACCESSORS                                        *
+ ****************************************************************************/
+/**
+ * Get the key associated with a RCS file transfer message if encrypted
+ * @param[in] content LinphoneContent object.
+ * @return The key to encrypt/decrypt the file associated to this content.
+ */
+const char *linphone_content_get_key(const LinphoneContent *content);
+
+/**
+ * Get the size of key associated with a RCS file transfer message if encrypted
+ * @param[in] content LinphoneContent object.
+ * @return The key size in bytes
+ */
+size_t linphone_content_get_key_size(const LinphoneContent *content);
+/**
+ * Set the key associated with a RCS file transfer message if encrypted
+ * @param[in] content LinphoneContent object.
+ * @param[in] key The key to be used to encrypt/decrypt file associated to this content.
+ */
+void linphone_content_set_key(LinphoneContent *content, const char *key, const size_t keyLength);
+
+/**
+ * Get the address of the crypto context associated with a RCS file transfer message if encrypted
+ * @param[in] content LinphoneContent object.
+ * @return The address of the pointer to the crypto context. Crypto context is managed(alloc/free)
+ *         by the encryption/decryption functions, so we give the address to store/retrieve the pointer
+ */
+void ** linphone_content_get_cryptoContext_address(LinphoneContent *content);
+
 #ifdef ANDROID
 void linphone_core_wifi_lock_acquire(LinphoneCore *lc);
 void linphone_core_wifi_lock_release(LinphoneCore *lc);
@@ -1132,7 +1176,10 @@ typedef struct _VTableReference  VTableReference;
 void v_table_reference_destroy(VTableReference *ref);
 
 void _linphone_core_add_listener(LinphoneCore *lc, LinphoneCoreVTable *vtable, bool_t autorelease);
-
+#ifdef VIDEO_ENABLED
+MSWebCam *linphone_call_get_video_device(const LinphoneCall *call);
+MSWebCam *get_nowebcam_device();
+#endif
 #ifdef __cplusplus
 }
 #endif
