@@ -92,7 +92,6 @@ static gint main_window_y=0;
 #endif
 static gboolean verbose=0;
 static gboolean quit_done=FALSE;
-static gboolean auto_answer = 0;
 static gchar * addr_to_call = NULL;
 static int start_option = START_LINPHONE;
 static gboolean no_video=FALSE;
@@ -139,7 +138,6 @@ static GOptionEntry linphone_options[]={
 	LINPHONE_OPTION("no-video",            '\0', G_OPTION_ARG_NONE,     (gpointer)&no_video,             N_("Start linphone with video disabled.")),
 	LINPHONE_OPTION("iconified",           '\0', G_OPTION_ARG_NONE,     (gpointer)&iconified,            N_("Start only in the system tray, do not show the main interface.")),
 	LINPHONE_OPTION("call",                'c',  G_OPTION_ARG_STRING,   &addr_to_call,                   N_("address to call right now")),
-	LINPHONE_OPTION("auto-answer",         'a',  G_OPTION_ARG_NONE,     (gpointer) & auto_answer,        N_("if set automatically answer incoming calls")),
 	LINPHONE_OPTION("workdir",             '\0', G_OPTION_ARG_STRING,   (gpointer) & workingdir,         N_("Specifiy a working directory (should be the base of the installation, eg: c:\\Program Files\\Linphone)")),
 	LINPHONE_OPTION("config",              '\0', G_OPTION_ARG_FILENAME, (gpointer) &custom_config_file,  N_("Configuration file")),
 	LINPHONE_OPTION("run-audio-assistant", '\0', G_OPTION_ARG_NONE,     (gpointer) &run_audio_assistant, N_("Run the audio assistant")),
@@ -345,8 +343,18 @@ static void linphone_gtk_configure_window(GtkWidget *w, const char *window_name)
 	if (icon_path) {
 		GdkPixbuf *pbuf=create_pixbuf(icon_path);
 		if(pbuf != NULL) {
-			gtk_window_set_icon(GTK_WINDOW(w),pbuf);
+			GList *pbuf_list = NULL;
+			GdkPixbuf *pbuf_16=gdk_pixbuf_scale_simple(pbuf, 16, 16, GDK_INTERP_BILINEAR);
+			GdkPixbuf *pbuf_32=gdk_pixbuf_scale_simple(pbuf, 32, 32, GDK_INTERP_BILINEAR);
+			pbuf_list = g_list_append(pbuf_list, pbuf);
+			pbuf_list = g_list_append(pbuf_list, pbuf_16);
+			pbuf_list = g_list_append(pbuf_list, pbuf_32);
+			gtk_window_set_icon_list(GTK_WINDOW(w), pbuf_list);
+			gtk_window_set_default_icon_list(pbuf_list);
+			g_object_unref(G_OBJECT(pbuf_16));
+			g_object_unref(G_OBJECT(pbuf_32));
 			g_object_unref(G_OBJECT(pbuf));
+			g_list_free(pbuf_list);
 		}
 	}
 }
@@ -1375,9 +1383,10 @@ static void linphone_gtk_call_state_changed(LinphoneCore *lc, LinphoneCall *call
 			linphone_gtk_create_in_call_view(call);
 			linphone_gtk_in_call_view_set_incoming(call);
 			linphone_gtk_status_icon_set_blinking(TRUE);
-			if (auto_answer)  {
+			if (linphone_gtk_get_ui_config_int("auto_answer", 0))  {
+				int delay = linphone_gtk_get_ui_config_int("auto_answer_delay", 2000);
 				linphone_call_ref(call);
-				g_timeout_add(2000,(GSourceFunc)linphone_gtk_auto_answer ,call);
+				g_timeout_add(delay, (GSourceFunc)linphone_gtk_auto_answer, call);
 			}
 		break;
 		case LinphoneCallResuming:
@@ -2101,8 +2110,11 @@ int main(int argc, char *argv[]){
 	/*for pulseaudio:*/
 	g_setenv("PULSE_PROP_media.role", "phone", TRUE);
 #endif
-
-	if ((lang=linphone_gtk_get_lang(config_file))!=NULL && lang[0]!='\0'){
+	lang=linphone_gtk_get_lang(config_file);
+	if (lang == NULL || lang[0]=='\0'){
+		lang = getenv("LANG");
+	}
+	if (lang && lang[0]!='\0'){
 #ifdef WIN32
 		char tmp[128];
 		snprintf(tmp,sizeof(tmp),"LANG=%s",lang);
@@ -2235,6 +2247,10 @@ core_start:
 	if (icon) gtk_status_icon_set_visible(icon,FALSE);
 #endif
 	free(progpath);
+	/*output a translated "hello" string to the terminal, which allows the builder to check that translations are working.*/
+	if (selftest){
+		printf(_("Hello\n"));
+	}
 	return 0;
 }
 
