@@ -1582,6 +1582,9 @@ void linphone_gtk_show_parameters(void){
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(linphone_gtk_get_widget(pb,"adaptive_rate_control")),
 	                         linphone_core_adaptive_rate_control_enabled(lc));
 
+	/* CALL PARAMS CONFIG */
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(linphone_gtk_get_widget(pb, "auto_answer_checkbox")), linphone_gtk_get_ui_config_int("auto_answer", 0));
+	gtk_spin_button_set_value(GTK_SPIN_BUTTON(linphone_gtk_get_widget(pb, "auto_answer_delay_spinbutton")), linphone_gtk_get_ui_config_int("auto_answer_delay", 2000));
 
 	/* UI CONFIG */
 	linphone_gtk_fill_langs(pb);
@@ -1770,3 +1773,13 @@ void linphone_gtk_dscp_edit_response(GtkWidget *dialog, guint response_id){
 	}
 	gtk_widget_destroy(dialog);
 }
+
+void linphone_gtk_enable_auto_answer(GtkToggleButton *checkbox, gpointer user_data) {
+	gboolean auto_answer_enabled = gtk_toggle_button_get_active(checkbox);
+	linphone_gtk_set_ui_config_int("auto_answer", auto_answer_enabled ? 1 : 0);
+}
+
+void linphone_gtk_auto_answer_delay_changed(GtkSpinButton *spinbutton, gpointer user_data) {
+	int delay = gtk_spin_button_get_value(spinbutton);
+	linphone_gtk_set_ui_config_int("auto_answer_delay", delay);
+}
